@@ -13,7 +13,7 @@ import h5py
 
 from sklearn.metrics import roc_auc_score, f1_score
 
-from cropharvest.bands import STATIC_BANDS, DYNAMIC_BANDS
+from cropharvest.bands import STATIC_BANDS, DYNAMIC_BANDS, BANDS, RAW_BANDS, REMOVED_BANDS
 from cropharvest.columns import RequiredColumns, NullableColumns
 from .config import (
     EXPORT_END_DAY,
@@ -28,10 +28,6 @@ from .utils import DATAFOLDER_PATH, load_normalizing_dict
 
 from typing import cast, Optional, Dict, Union, Tuple, List, Sequence
 
-REMOVED_BANDS = ["B1", "B10"]
-RAW_BANDS = DYNAMIC_BANDS + STATIC_BANDS
-BANDS = [x for x in DYNAMIC_BANDS if x not in REMOVED_BANDS] + STATIC_BANDS + ["NDVI"]
-
 
 @dataclass
 class DataInstance:
@@ -166,6 +162,12 @@ class TestInstance:
 
 
 class Engineer:
+    """
+    This engineer creates features with BANDS defined in bands.py.
+    If the engineer changes, the bands there will need to change as
+    well.
+    """
+
     def __init__(self, data_folder: Path = DATAFOLDER_PATH) -> None:
         self.data_folder = data_folder
         self.eo_files = data_folder / "eo_data"
@@ -572,7 +574,7 @@ class Engineer:
         skipped_files: int = 0
         num_new_files: int = 0
         for file_path in tqdm(list(self.eo_files.glob("*.tif"))):
-            file_index, dataset = self.process_filename(file_path.name)
+            file_index, dataset = self.process_filename(file_path.stem)
             file_name = f"{file_index}_{dataset}.h5"
             if (checkpoint) & ((arrays_dir / file_name).exists()):
                 # we check if the file has already been written
