@@ -138,13 +138,15 @@ class EarthEngineExporter:
     ) -> geopandas.GeoDataFrame:
         labels = geopandas.read_file(DATAFOLDER_PATH / LABELS_FILENAME)
         export_end_year = pd.to_datetime(labels[RequiredColumns.EXPORT_END_DATE]).dt.year
-        labels["end_date"] = export_end_year.apply(lambda x: date(x, 12, 12))
+        labels["end_date"] = export_end_year.apply(
+            lambda x: date(x, EXPORT_END_MONTH, EXPORT_END_DAY)
+        )
         labels = labels.assign(
             start_date=lambda x: x["end_date"]
             - timedelta(days=DAYS_PER_TIMESTEP * DEFAULT_NUM_TIMESTEPS)
         )
-        labels = labels.assign(
-            export_identifier=lambda x: f"{x['index']}-{x[RequiredColumns.DATASET]}"
+        labels["export_identifier"] = labels.apply(
+            lambda x: f"{x['index']}-{x[RequiredColumns.DATASET]}", axis=1
         )
         if dataset:
             labels = labels[labels.dataset == dataset]
@@ -421,8 +423,11 @@ class EarthEngineExporter:
         metres_per_polygon: Optional[int] = 10000,
         file_dimensions: Optional[int] = None,
     ) -> Dict[str, bool]:
+
+        if start_date > end_date:
+            raise ValueError(f"Start date {start_date} is after end date {end_date}")
+
         ee_bbox = EEBoundingBox.from_bounding_box(bounding_box=bbox, padding_metres=0)
-        general_identifier = f"{bbox_name}_{str(start_date)}_{str(end_date)}"
         if metres_per_polygon is not None:
             regions = ee_bbox.to_polygons(metres_per_patch=metres_per_polygon)
             ids = [f"batch_{i}/{i}" for i in range(len(regions))]
@@ -434,7 +439,7 @@ class EarthEngineExporter:
         for identifier, region in zip(ids, regions):
             return_obj[identifier] = self._export_for_polygon(
                 polygon=region,
-                polygon_identifier=f"{general_identifier}/{identifier}",
+                polygon_identifier=f"{bbox_name}/{identifier}",
                 start_date=start_date,
                 end_date=end_date,
                 file_dimensions=file_dimensions,
